package
Version:
v0.0.0-...-640b46e
Opens a new window with list of versions in this module.
Published: Mar 6, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Server string `json:"server"`
Master Server `json:"master"`
Backup string `json:"backup"`
RecursiveNS []string `json:"recursive-ns"`
}
type Server struct {
RPC string `json:"rpc"`
IP string `json:"ip"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.